@@ -1,5 +1,5 @@
 package Adapter::Async::Model;
-$Adapter::Async::Model::VERSION = '0.017';
+$Adapter::Async::Model::VERSION = '0.018';
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ Adapter::Async::Model - helper class for defining models
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 DESCRIPTION
 
@@ -131,7 +131,7 @@ sub import {
 				return $self->$type->get_key($v) if shift;
 
 				my $item = $create->($v);
-				$log->tracef("Set %s on %s for %s to %s via %s", $v, $type, "$self", $item,$self->$type);
+				$log->tracef("Set %s on %s for %s to %s via %s", $v, $type, "$self", $item, ''.$self->$type);
 				$self->$type->set_key(
 					$v => $item
 				)->transform(
@@ -171,7 +171,7 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
