@@ -1,5 +1,5 @@
 package Adapter::Async::UnorderedMap;
-$Adapter::Async::UnorderedMap::VERSION = '0.017';
+$Adapter::Async::UnorderedMap::VERSION = '0.018';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Adapter::Async::UnorderedMap - API for dealing with key => value maps
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 DESCRIPTION
 
@@ -151,7 +151,7 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
